// $Id$
/**
* Copyright (C) 2013 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.editor.view.checklist;

import java.util.UUID;

import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IMemento;
import org.eclipse.ui.IPersistable;
import org.eclipse.ui.IPersistableElement;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.model.taxon.Classification;
import eu.etaxonomy.cdm.model.taxon.TaxonNode;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 *
 * @author a.oppermann
 * @date 25.04.2014
 *
 */
public class ChecklistEditorInput implements IEditorInput, IPersistable {

    /**
     * The selected classification
     */
    private TaxonNode taxonNode = null;

    private Classification classification = null;

    private final ConversationHolder conversationHolder;


    /**
     * Creates an editor input for the {@link ChecklistView} with the currently selected TaxonNode
     * and its childNodes.
     * @param taxonNode
     */
    public ChecklistEditorInput(TaxonNode taxonNode){
        super();
        this.conversationHolder = CdmStore.createConversation();
        this.taxonNode = CdmStore.getCurrentApplicationConfiguration().getTaxonNodeService().load(taxonNode.getUuid());
        classification = taxonNode.getClassification();
    }

    /**
     * Creates an editor input for the {@link ChecklistView} with the currently selected classification.
     * @param classificationUuid
     */
    public ChecklistEditorInput(Classification classification) {
        super();
        this.conversationHolder = CdmStore.createConversation();
        this.classification = CdmStore.getCurrentApplicationConfiguration().getClassificationService().load(classification.getUuid());

    }



    /* (non-Javadoc)
     * @see org.eclipse.core.runtime.IAdaptable#getAdapter(java.lang.Class)
     */
    @Override
    public Object getAdapter(Class adapter) {
        // TODO Auto-generated method stub
        return null;
    }

    /* (non-Javadoc)
     * @see org.eclipse.ui.IEditorInput#exists()
     */
    @Override
    public boolean exists() {
        return false;
    }

    /* (non-Javadoc)
     * @see org.eclipse.ui.IEditorInput#getImageDescriptor()
     */
    @Override
    public ImageDescriptor getImageDescriptor() {
        // TODO Auto-generated method stub
        return null;
    }

    /* (non-Javadoc)
     * @see org.eclipse.ui.IEditorInput#getName()
     */
    @Override
    public String getName() {
        if(taxonNode != null){
            return taxonNode.getTaxon().getName().getTitleCache();
        }else{
            return classification.getTitleCache();
        }
    }

    /* (non-Javadoc)
     * @see org.eclipse.ui.IEditorInput#getPersistable()
     */
    @Override
    public IPersistableElement getPersistable() {
        return null;
    }

    /* (non-Javadoc)
     * @see org.eclipse.ui.IEditorInput#getToolTipText()
     */
    @Override
    public String getToolTipText() {
        return classification.getTitleCache();
    }

    /**
     * @return the taxonNode
     */
    public TaxonNode getTaxonNode() {
        return taxonNode;
    }

    /**
     * @return classification
     */
    public Classification getClassification(){
    	return classification;
    }

    /**
     * @return the conversationHolder
     */
    public ConversationHolder getConversationHolder() {
        return conversationHolder;
    }



    /* (non-Javadoc)
     * @see java.lang.Object#hashCode()
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((classification == null) ? 0 : classification.hashCode());
        result = prime * result + ((taxonNode == null) ? 0 : taxonNode.hashCode());
        return result;
    }

    /* (non-Javadoc)
     * @see java.lang.Object#equals(java.lang.Object)
     */
    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        ChecklistEditorInput other = (ChecklistEditorInput) obj;
        if (classification == null) {
            if (other.classification != null) {
                return false;
            }
        } else if (!classification.equals(other.classification)) {
            return false;
        }
        if (taxonNode == null) {
            if (other.taxonNode != null) {
                return false;
            }
        } else if (!taxonNode.equals(other.taxonNode)) {
            return false;
        }
        return true;
    }

    /* (non-Javadoc)
     * @see org.eclipse.ui.IPersistable#saveState(org.eclipse.ui.IMemento)
     */
    @Override
    public void saveState(IMemento memento) {
        UUID uuid = classification.getUuid();
    }

}
