// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.editor.view.concept;

import org.eclipse.jface.viewers.DelegatingStyledCellLabelProvider.IStyledLabelProvider;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.jface.viewers.StyledString;
import org.eclipse.swt.graphics.Image;

import eu.etaxonomy.cdm.model.common.Language;
import eu.etaxonomy.cdm.model.common.Representation;
import eu.etaxonomy.cdm.model.reference.IReference;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.cdm.model.taxon.TaxonRelationship;
import eu.etaxonomy.cdm.model.taxon.TaxonRelationshipType;
import eu.etaxonomy.taxeditor.editor.EditorUtil;
import eu.etaxonomy.taxeditor.editor.MultiPageTaxonEditor;
import eu.etaxonomy.taxeditor.model.ImageResources;
import eu.etaxonomy.taxeditor.model.TaxonRelationshipTypeInverseContainer;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * @author n.hoffmann
 * @created Jan 24, 2011
 * @version 1.0
 */
public class ConceptLabelProvider extends LabelProvider implements IStyledLabelProvider {

	/* (non-Javadoc)
	 * @see org.eclipse.jface.viewers.LabelProvider#getImage(java.lang.Object)
	 */
	@Override
	public Image getImage(Object element) {
		if(element instanceof TaxonRelationship){
			return getTaxonRelationshipImage((TaxonRelationship) element);
		}
		return super.getImage(element);
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.jface.viewers.ColumnLabelProvider#getText(java.lang.Object)
	 */
	@Override
	public String getText(Object element) {
		if(element instanceof TaxonRelationship){
			return formatRelationship((TaxonRelationship) element);
		}
		
		return "";
	}
	
	/**
	 * Creates a string that holds a representation of the {@link TaxonRelationship} in relation to
	 * the accepted taxon of the currently active {@link MultiPageTaxonEditor}.
	 * 
	 * @param relationship
	 * @return a formatted String representation of the relationship
	 */
	private String formatRelationship(TaxonRelationship relationship){
		Taxon sourceTaxon = EditorUtil.getActiveMultiPageTaxonEditor().getTaxon();
		TaxonRelationshipTypeInverseContainer container = TaxonRelationshipTypeInverseContainer.CreateFromSource(sourceTaxon, relationship);
		Taxon relatedTaxon = TaxonRelationshipTypeInverseContainer.RelatedTaxon(sourceTaxon, relationship);
		String string = String.format("%s %s", container.getAbbreviatedLabel(), relatedTaxon);
		
		return string;
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.jface.viewers.DelegatingStyledCellLabelProvider.IStyledLabelProvider#getStyledText(java.lang.Object)
	 */
	@Override
	public StyledString getStyledText(Object element) {
		return  new StyledString(getText(element), StyledString.QUALIFIER_STYLER);
	}

	/**
	 * TODO we will get the proper relationship symbol from the type's abbreviated label as a character.
	 * The image may be omitted then.
	 * 
	 * @param type
	 * @return
	 */
	private Image getTaxonRelationshipImage(TaxonRelationship relationship) {
		TaxonRelationshipType type = (relationship).getType();
		return ImageResources.getImage(ImageResources.CONCEPT_ICON);
	}
}
