// $Id$
/**
* Copyright (C) 2013 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.editor.view.dataimport.transientServices;

import java.util.Collection;

import org.springframework.security.authentication.ProviderManager;
import org.springframework.transaction.PlatformTransactionManager;
import org.springframework.transaction.TransactionStatus;

import eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration;
import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.api.service.IAgentService;
import eu.etaxonomy.cdm.api.service.IClassificationService;
import eu.etaxonomy.cdm.api.service.ICollectionService;
import eu.etaxonomy.cdm.api.service.ICommonService;
import eu.etaxonomy.cdm.api.service.IDatabaseService;
import eu.etaxonomy.cdm.api.service.IDescriptionService;
import eu.etaxonomy.cdm.api.service.IEntityConstraintViolationService;
import eu.etaxonomy.cdm.api.service.IEntityValidationService;
import eu.etaxonomy.cdm.api.service.IFeatureNodeService;
import eu.etaxonomy.cdm.api.service.IFeatureTreeService;
import eu.etaxonomy.cdm.api.service.IGrantedAuthorityService;
import eu.etaxonomy.cdm.api.service.IGroupService;
import eu.etaxonomy.cdm.api.service.IIdentificationKeyService;
import eu.etaxonomy.cdm.api.service.ILocationService;
import eu.etaxonomy.cdm.api.service.IMediaService;
import eu.etaxonomy.cdm.api.service.INameService;
import eu.etaxonomy.cdm.api.service.IOccurrenceService;
import eu.etaxonomy.cdm.api.service.IPolytomousKeyNodeService;
import eu.etaxonomy.cdm.api.service.IPolytomousKeyService;
import eu.etaxonomy.cdm.api.service.IReferenceService;
import eu.etaxonomy.cdm.api.service.IService;
import eu.etaxonomy.cdm.api.service.ITaxonNodeService;
import eu.etaxonomy.cdm.api.service.ITaxonService;
import eu.etaxonomy.cdm.api.service.ITermService;
import eu.etaxonomy.cdm.api.service.IUserService;
import eu.etaxonomy.cdm.api.service.IVocabularyService;
import eu.etaxonomy.cdm.api.service.IWorkingSetService;
import eu.etaxonomy.cdm.api.service.molecular.IAmplificationService;
import eu.etaxonomy.cdm.api.service.molecular.IPrimerService;
import eu.etaxonomy.cdm.api.service.molecular.ISequenceService;
import eu.etaxonomy.cdm.model.common.CdmBase;
import eu.etaxonomy.cdm.model.occurrence.SpecimenOrObservationBase;
import eu.etaxonomy.cdm.persistence.hibernate.permission.ICdmPermissionEvaluator;

/**
 * @author pplitzner
 * @date 26.09.2013
 *
 */
public class TransientCdmRepository implements ICdmApplicationConfiguration {

    private final ICdmApplicationConfiguration defaultApplicationConfiguration;
    private TransientOccurenceService occurenceService;

    public Collection<SpecimenOrObservationBase<?>> getUnits(){
        return occurenceService.getUnits();
    }

    /**
     * @param defaultApplicationConfiguration
     */
    public TransientCdmRepository(ICdmApplicationConfiguration defaultApplicationConfiguration) {
        this.defaultApplicationConfiguration = defaultApplicationConfiguration;
        this.occurenceService = (TransientOccurenceService) getOccurrenceService();
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#NewConversation()
     */
    @Override
    public ConversationHolder NewConversation() {
        return defaultApplicationConfiguration.NewConversation();
    }

    /**
     * @param arg0
     * @param arg1
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#authenticate(java.lang.String, java.lang.String)
     */
    @Override
    public void authenticate(String arg0, String arg1) {
        defaultApplicationConfiguration.authenticate(arg0, arg1);
    }

    /**
     * @param arg0
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#commitTransaction(org.springframework.transaction.TransactionStatus)
     */
    @Override
    public void commitTransaction(TransactionStatus arg0) {
        defaultApplicationConfiguration.commitTransaction(arg0);
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getAgentService()
     */
    @Override
    public IAgentService getAgentService() {
        return new TransientAgentService(defaultApplicationConfiguration.getAgentService());
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getAuthenticationManager()
     */
    @Override
    public ProviderManager getAuthenticationManager() {
        return defaultApplicationConfiguration.getAuthenticationManager();
    }

    /**
     * @param arg0
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getBean(java.lang.String)
     */
    @Override
    public Object getBean(String arg0) {
        return defaultApplicationConfiguration.getBean(arg0);
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getClassificationService()
     */
    @Override
    public IClassificationService getClassificationService() {
        return new TransientClassificationService(defaultApplicationConfiguration.getClassificationService());
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getCollectionService()
     */
    @Override
    public ICollectionService getCollectionService() {
        return new TransientCollectionService(defaultApplicationConfiguration.getCollectionService());
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getCommonService()
     */
    @Override
    public ICommonService getCommonService() {
        return defaultApplicationConfiguration.getCommonService();
//        return new TransientCommonService(defaultApplicationConfiguration.getCommonService());
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getDatabaseService()
     */
    @Override
    public IDatabaseService getDatabaseService() {
        return defaultApplicationConfiguration.getDatabaseService();
//        return new TransientDatabaseService(defaultApplicationConfiguration.getDatabaseService());
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getDescriptionService()
     */
    @Override
    public IDescriptionService getDescriptionService() {
        return new TransientDescriptionService(defaultApplicationConfiguration.getDescriptionService());
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getFeatureNodeService()
     */
    @Override
    public IFeatureNodeService getFeatureNodeService() {
        return defaultApplicationConfiguration.getFeatureNodeService();
//        return new TransientFeatureNodeService(defaultApplicationConfiguration.getFeatureNodeService());
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getFeatureTreeService()
     */
    @Override
    public IFeatureTreeService getFeatureTreeService() {
        return defaultApplicationConfiguration.getFeatureTreeService();
//        return new TransientFeatureTreeService(defaultApplicationConfiguration.getFeatureTreeService());
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getGrantedAuthorityService()
     */
    @Override
    public IGrantedAuthorityService getGrantedAuthorityService() {
        return defaultApplicationConfiguration.getGrantedAuthorityService();
//        return new TransientGrantedAuthorityService(defaultApplicationConfiguration.getGrantedAuthorityService());
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getGroupService()
     */
    @Override
    public IGroupService getGroupService() {
        return defaultApplicationConfiguration.getGroupService();
//        return new TransientGroupService(defaultApplicationConfiguration.getGroupService());
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getIdentificationKeyService()
     */
    @Override
    public IIdentificationKeyService getIdentificationKeyService() {
        return defaultApplicationConfiguration.getIdentificationKeyService();
//        return new TransientIdentificationService(defaultApplicationConfiguration.getIdentificationKeyService());
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getLocationService()
     */
    @Override
    public ILocationService getLocationService() {
        return defaultApplicationConfiguration.getLocationService();
//        return new TransientLocationService(defaultApplicationConfiguration.getLocationService());
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getMainService()
     */
    @Override
    public IService<CdmBase> getMainService() {
        return defaultApplicationConfiguration.getMainService();
//        return new TransientMainService(defaultApplicationConfiguration.getMainService());
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getMediaService()
     */
    @Override
    public IMediaService getMediaService() {
        return defaultApplicationConfiguration.getMediaService();
//        return new TransientMediaService(defaultApplicationConfiguration.getMediaService());
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getNameService()
     */
    @Override
    public INameService getNameService() {
        return new TransientNameService(defaultApplicationConfiguration.getNameService());
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getOccurrenceService()
     */
    @Override
    public IOccurrenceService getOccurrenceService() {
        if(occurenceService==null){
            occurenceService = new TransientOccurenceService(defaultApplicationConfiguration.getOccurrenceService());
        }
        return occurenceService;
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getPermissionEvaluator()
     */
    @Override
    public ICdmPermissionEvaluator getPermissionEvaluator() {
        return defaultApplicationConfiguration.getPermissionEvaluator();
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getPolytomousKeyNodeService()
     */
    @Override
    public IPolytomousKeyNodeService getPolytomousKeyNodeService() {
        return defaultApplicationConfiguration.getPolytomousKeyNodeService();
//        return new TransientPolytomousKeyNodeService(defaultApplicationConfiguration.getPolytomousKeyNodeService());
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getPolytomousKeyService()
     */
    @Override
    public IPolytomousKeyService getPolytomousKeyService() {
        return defaultApplicationConfiguration.getPolytomousKeyService();
//        return new TransientPolytomousKeyService(defaultApplicationConfiguration.getPolytomousKeyService());
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getReferenceService()
     */
    @Override
    public IReferenceService getReferenceService() {
        return new TransientReferenceService(defaultApplicationConfiguration.getReferenceService());
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getTaxonNodeService()
     */
    @Override
    public ITaxonNodeService getTaxonNodeService() {
        return defaultApplicationConfiguration.getTaxonNodeService();
//        return new TransientTaxonNodeService(defaultApplicationConfiguration.getTaxonNodeService());
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getTaxonService()
     */
    @Override
    public ITaxonService getTaxonService() {
        return new TransientTaxonService(defaultApplicationConfiguration.getTaxonService());
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getTermService()
     */
    @Override
    public ITermService getTermService() {
        return new TransientTermService(defaultApplicationConfiguration.getTermService());
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getTransactionManager()
     */
    @Override
    public PlatformTransactionManager getTransactionManager() {
        return defaultApplicationConfiguration.getTransactionManager();
    }

    @Override
    public IUserService getUserService() {
        return defaultApplicationConfiguration.getUserService();
//        return new TransientUserService(defaultApplicationConfiguration.getUserService());
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration#getVocabularyService()
     */
    @Override
    public IVocabularyService getVocabularyService() {
        return defaultApplicationConfiguration.getVocabularyService();
//        return new TransientVocabularyService(defaultApplicationConfiguration.getVocabularyService());
    }

    @Override
    public IWorkingSetService getWorkingSetService() {
        return defaultApplicationConfiguration.getWorkingSetService();
//        return new TransientWorkingSetService(defaultApplicationConfiguration.getWorkingSetService());
    }

    @Override
    public TransactionStatus startTransaction() {
        return defaultApplicationConfiguration.startTransaction();
    }


    @Override
    public TransactionStatus startTransaction(Boolean arg0) {
        return defaultApplicationConfiguration.startTransaction(arg0);
    }

    @Override
    public IPrimerService getPrimerService() {
        return defaultApplicationConfiguration.getPrimerService();
    }

    @Override
    public IAmplificationService getAmplificationService() {
        return defaultApplicationConfiguration.getAmplificationService();
    }

    @Override
    public ISequenceService getSequenceService() {
        return defaultApplicationConfiguration.getSequenceService();
    }

	@Override
	public IEntityConstraintViolationService getEntityConstraintViolationService() {
		return defaultApplicationConfiguration.getEntityConstraintViolationService();
	}

	@Override
	public IEntityValidationService getEntityValidationService() {
		return defaultApplicationConfiguration.getEntityValidationService();
	}
}
