/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.editor.view.descriptive.operation;

import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.operations.IUndoContext;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;

import eu.etaxonomy.cdm.model.description.DescriptionBase;
import eu.etaxonomy.cdm.model.description.DescriptionElementBase;
import eu.etaxonomy.taxeditor.model.MessagingUtils;
import eu.etaxonomy.taxeditor.operation.AbstractPostTaxonOperation;
import eu.etaxonomy.taxeditor.operation.IPostOperationEnabled;

/**
 * <p>DeleteDescriptionElementOperation class.</p>
 *
 * @author p.ciardelli
 * @created 05.02.2009
 * @version 1.0
 */
public class DeleteDescriptionElementOperation extends AbstractPostTaxonOperation {
	
	private DescriptionElementBase element;
	private DescriptionBase description = null;

	/**
	 * <p>Constructor for DeleteDescriptionElementOperation.</p>
	 *
	 * @param label a {@link java.lang.String} object.
	 * @param undoContext a {@link org.eclipse.core.commands.operations.IUndoContext} object.
	 * @param element a {@link eu.etaxonomy.cdm.model.description.DescriptionElementBase} object.
	 * @param postOperationEnabled a {@link eu.etaxonomy.taxeditor.operation.IPostOperationEnabled} object.
	 */
	public DeleteDescriptionElementOperation(String label, IUndoContext undoContext,
			DescriptionElementBase element, IPostOperationEnabled postOperationEnabled) {
		super(label, undoContext, postOperationEnabled);
		
		this.element = element;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#execute(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	/** {@inheritDoc} */
	@Override
	public IStatus execute(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		
		description = element.getInDescription();
		
		monitor.worked(20);
		
		// Remove element from description
		if (description == null) {
			MessagingUtils.error(this.getClass(), "Couldn't find element's description!", null);
		} else {
			description.removeElement(element);
		}
		monitor.worked(40);

        // Redraw editor if exists
		return postExecute(null);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#redo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	/** {@inheritDoc} */
	@Override
	public IStatus redo(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		return execute(monitor, info);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#undo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	/** {@inheritDoc} */
	@Override
	public IStatus undo(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {

		description.addElement(element);
		
		return postExecute(element);
	}
}
