/**
 *
 */
package eu.etaxonomy.taxeditor.editor.view.media.handler;

import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.common.NotDefinedException;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.TreePath;
import org.eclipse.jface.viewers.TreeSelection;
import org.eclipse.ui.IEditorPart;
import org.eclipse.ui.IWorkbenchPart;
import org.eclipse.ui.forms.editor.FormEditor;
import org.eclipse.ui.handlers.HandlerUtil;

import eu.etaxonomy.cdm.model.description.DescriptionBase;
import eu.etaxonomy.taxeditor.editor.EditorUtil;
import eu.etaxonomy.taxeditor.editor.view.media.operation.AddMediaToImageGalleryOperation;
import eu.etaxonomy.taxeditor.model.AbstractUtility;
import eu.etaxonomy.taxeditor.model.MessagingUtils;
import eu.etaxonomy.taxeditor.operation.AbstractPostOperation;
import eu.etaxonomy.taxeditor.operation.IPostOperationEnabled;

/**
 * <p>CreateMediaHandler class.</p>
 *
 * @author p.ciardelli
 * @version $Id: $
 */
public class CreateMediaHandler extends AbstractHandler {

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.IHandler#execute(org.eclipse.core.commands.ExecutionEvent)
	 */
	/** {@inheritDoc} */
	@Override
    public Object execute(ExecutionEvent event) throws ExecutionException {
		IWorkbenchPart part = HandlerUtil.getActivePart(event);
		IPostOperationEnabled postOperationEnabled = (part instanceof IPostOperationEnabled) ? (IPostOperationEnabled) part : null;


		DescriptionBase description = null;

		IEditorPart editor = HandlerUtil.getActiveEditor(event);
		if (editor instanceof FormEditor) {
			editor = ((FormEditor) editor).getActiveEditor();
		}

		ISelection selection = HandlerUtil.getCurrentSelection(event);
		if (selection instanceof TreeSelection) {
			TreePath[] paths = ((TreeSelection) selection).getPaths();

			int count = paths[0].getSegmentCount();

			for (int i = 0; i < count; i++ ) {
				if (paths[0].getSegment(i) instanceof DescriptionBase) {
					description = (DescriptionBase) paths[0].getSegment(i);
					break;
				}
			}
		}

		if(description != null){
			executeOperation(event, postOperationEnabled, description);
		}

		return null;
	}

    /**
     * @param event
     * @param postOperationEnabled
     * @param description
     */
    protected void executeOperation(ExecutionEvent event, IPostOperationEnabled postOperationEnabled,
            DescriptionBase description) {
        AbstractPostOperation operation = null;
        try {
        	// TODO use undo context specific to editor
        	operation = new AddMediaToImageGalleryOperation(event.getCommand().getName(),
        			EditorUtil.getUndoContext(), description, postOperationEnabled);
        	AbstractUtility.executeOperation(operation);
        } catch (NotDefinedException e) {
        	MessagingUtils.warn(getClass(), "Command name not set.");
        }
    }

}
